pywr.optimisation package — Pywr 0.5dev documentation

# pywr.optimisation package

## Submodules

## pywr.optimisation.moea module

class `pywr.optimisation.moea.` `InspyredOptimisationModel`

  Bases: `pywr._model.Model`

  A pywr.core.Model subclass to enable optimisation using inspyred.

  This classes overloads Model.setup() to create cached variable and objective maps to use with inspyred.

  A generator, bounder and evaluator method are provided to use with the inspyred algorithms.

  `bounder`(candidate, args)
  `evaluator`(candidates, args)
  `generator`(random, args)
  `setup`()

    Setup the model for the first time or if it has changed since last run.

## Module contents